==> dhall-yaml-1.2.12-2-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-ECV4s6w3sRyHHo7Jbl55m1
key:                  dhall-yaml-1.2.12-ECV4s6w3sRyHHo7Jbl55m1
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  df148af4c53b8a194819c860a3c3ca83
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-ECV4s6w3sRyHHo7Jbl55m1
depends:
    HsYAML-0.2.1.3-5OxewlPL57e10hHIVWXMUn
    HsYAML-aeson-0.2.0.1-E4zm2RCuZwl6cbYRRXxKE4
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.41.2-DiDav7kEbPZLTXgwTtPGqR
    dhall-json-1.7.11-19OpDys1BrcApXMTPZoAh0
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z text-2.0.2
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.12-3-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-12DjzKqtlkp5Hwkt0cDw0q
key:                  dhall-yaml-1.2.12-12DjzKqtlkp5Hwkt0cDw0q
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  3323cd7d25480b9c27276e28b48f7712
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-12DjzKqtlkp5Hwkt0cDw0q
depends:
    HsYAML-0.2.1.3-5OxewlPL57e10hHIVWXMUn
    HsYAML-aeson-0.2.0.1-E4zm2RCuZwl6cbYRRXxKE4
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.1-1Sq0RLHVQS9wRx7I3v9sA
    dhall-json-1.7.12-GazNyNBKcf6HPYkdHrJeD8
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z text-2.0.2
    vector-0.13.1.0-93FGbMU4lvK4yKJkYGTpJX

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
